@@ -1,6 +1,6 @@
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from attributes.widgets import AttributesFormFieldWidget
 from attributes.forms import AttributesForm
